rfc1036's (Marco d'Itri) Intelligent WHOIS client fork extended for Python usage.

## usage

```python
import cwhois

print(cwhois.query('example.com'))
```

## install

either `python setup.py install` or `python -m pip install .` should work depending on your setup
